@@ -36,7 +36,7 @@ class ScoringFunctionComponentNameEnum:
     RH_CLINT_PIP = "rh-clint"
     SOLUBILITY_DD_PIP = "solubility-dd"
     HERG_PIP = "herg"
-    RAT_PK_PIP = "pip-rat-pk"
+    RAT_PK_PIP = "rat-pk"
     REACTION_FILTERS = "reaction_filters"
     CLAB_TOP_20 = "clab_top_20"
 
